@@ -23,9 +23,9 @@ package Linux::AIO;
 use base 'Exporter';
 
 BEGIN {
-   $VERSION = 0.011;
+   $VERSION = 0.11;
 
-   @EXPORT = qw(aio_read aio_write aio_open aio_close);
+   @EXPORT = qw(aio_read aio_write aio_open aio_close aio_stat aio_lstat);
    @EXPORT_OK = qw(poll_fileno poll_cb min_parallel max_parallel nreqs);
 
    require XSLoader;
@@ -59,13 +59,6 @@ You can use Event to multiplex, e.g.:
 
 Returns the number of requests currently outstanding.
 
-=item aio_read($fh,$offset,$length, $data,$dataoffset,$callback)
-aio_write($fh,$offset,$length, $data,$dataoffset,$callback)
-
-Reads or writes C<length> bytes from the specified C<fh> and C<offset>
-into the scalar given by C<data> and offset C<dataoffset> and calls the
-callback without the actual number of bytes read (or undef on error).
-
 =item aio_open($pathname, $flags, $mode, $callback)
 
 Asynchronously open or create a file and call the callback with the
@@ -75,6 +68,26 @@ filedescriptor.
 
 Asynchronously close a file and call the callback with the result code.
 
+=item aio_read($fh,$offset,$length, $data,$dataoffset,$callback)
+
+=item aio_write($fh,$offset,$length, $data,$dataoffset,$callback)
+
+Reads or writes C<length> bytes from the specified C<fh> and C<offset>
+into the scalar given by C<data> and offset C<dataoffset> and calls the
+callback without the actual number of bytes read (or undef on error).
+
+=item aio_stat($fh_or_path,$callback)
+
+=item aio_lstat($fh,$callback)
+
+Works like perl's C<stat> or C<lstat> in void context, i.e. the callback
+will be called after the stat and the results will be available using
+C<stat _> or C<-s _> etc...
+
+Currently, the stats are always 64-bit-stats, i.e. instead of returning an
+error when stat'ing a large file, the results will be silently truncated
+unless perl itself is compiled with large file support.
+
 =cut
 
 END {
@@ -89,7 +102,8 @@ END {
 
 This module has not yet been extensively tested. Watch out!
 
-   - aio_stat/lstat are seriously missing here.
+   - perl-threads/fork interaction poorly tested.
+   - aio_open gives a fd, but all other functions expect a filehandle.
 
 =head1 SEE ALSO
 
